# Table of Contents

- [setting-up-your-organization-s-s-user-administrator](<./setting-up-your-organization-s-s-user-administrator.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Setting Up Your Organization's S-User Administrator](<./Setting-Up-Your-Organizations-S-User-Administrator.md>)
  - [Overview](<./Setting-Up-Your-Organizations-S-User-Administrator/Overview.md>)
  - [Creating Your First S-User Administrator](<./Setting-Up-Your-Organizations-S-User-Administrator/Creating-Your-First-S-User-Administrator.md>)
  - [Creating Additional S-User Administrators](<./Setting-Up-Your-Organizations-S-User-Administrator/Creating-Additional-S-User-Administrators.md>)
  - [We'd love your feedback!](<./Setting-Up-Your-Organizations-S-User-Administrator/Wed-love-your-feedback.md>)
